@@ -1,10 +1,10 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-24 13:57:15 mtw>
+# Last changed Time-stamp: <2015-06-29 15:52:09 mtw>
 
 package Bio::ViennaNGS::SpliceJunc;
 
 use Exporter;
-use version; our $VERSION = qv('0.14');
+use version; our $VERSION = qv('0.15');
 use strict;
 use warnings;
 use Data::Dumper;
@@ -30,7 +30,7 @@ our @EXPORT_OK = qw(bed6_ss_from_bed12 bed6_ss_from_rnaseq
 sub bed6_ss_from_bed12{
   my ($bed12,$dest,$window,$can,$fastaobjR) = @_;
   my ($i,$tr_name,$pos5,$pos3);
-  my ($splicesites,$c,$totalsj,$cansj) = 0x4;
+  my ($splicesites,$c,$totalsj,$cansj) = (0)x4;
   my @bedline = ();
   my $this_function = (caller(0))[3];
 
@@ -512,9 +512,9 @@ strand. In 5' to 3' direction of the forward strandm this junction
 reads CT->AC. A splice junction is canonical if its motif corresponds
 to one of the following cases:
 
-5'===]GT|CT....AG|AC[====3' ie GT->AG or CT->AC
-5'===]GC|CT....AG|GC[====3' ie GC->AG or CT->GC
-5'===]AT|GT....AC|AT[====3' ie AT->AC or GT->AT
+  5'===]GT|CT....AG|AC[====3' ie GT->AG or CT->AC
+  5'===]GC|CT....AG|GC[====3' ie GC->AG or CT->GC
+  5'===]AT|GT....AC|AT[====3' ie AT->AC or GT->AT
 
 =back
 
