@@ -1,10 +1,10 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-24 13:57:38 mtw>
+# Last changed Time-stamp: <2015-06-29 15:52:40 mtw>
 
 package Bio::ViennaNGS::UCSC;
 
 use Exporter;
-use version; our $VERSION = qv('0.14');
+use version; our $VERSION = qv('0.15');
 use strict;
 use warnings;
 use Template;
@@ -19,7 +19,12 @@ use Bio::ViennaNGS::Util qw(fetch_chrom_sizes bed2bigBed);
 
 our @ISA = qw(Exporter);
 
-our @EXPORT_OK = qw( make_assembly_hub make_track_hub );
+our @EXPORT_OK = qw( make_assembly_hub make_track_hub retrieve_color
+make_track make_multi_bigwig_container_track
+make_bigwig_container_track retrieve_bigwig_tracks
+retrieve_bigbed_url_tracks parse_fasta_header valid_ncbi_accession
+modify_fasta_header make_group retrieve_chromosome_size
+write_chromosome_size_file convert_tracks);
 
 our @EXPORT = ();
 
@@ -530,13 +535,13 @@ sub make_bigwig_track{
 
 sub valid_ncbi_accession{
   # receives a NCBI accession ID, with or without version number
-  # returns NCBI accession ID without version number
+  # checks for validity and returns the accession number as is
   my $acc = shift;
   if ($acc =~ /^(N[CST]\_\d{6})\.\d+?$/){
-    return $acc; # NCBI accession ID without version
+    return $acc;
   }
   elsif ($acc =~ /^(N[CST]\_\d{6})$/){
-    return $1; # NCBI accession ID without version
+    return $1;
   }
   else {
     return 0;
@@ -552,7 +557,6 @@ sub parse_fasta_header{
   close $file;
   #>gi|556503834|ref|NC_000913.3| Escherichia coli str. K-12 substr. MG1655
   if($fastaheader=~/^>gi/){
-    print LOG "#NCBI fasta header detected\n";
     my @headerfields = split(/\|/, $fastaheader);
     my $accession = $headerfields[3];
     my $scientificName = $headerfields[4];
@@ -563,13 +567,11 @@ sub parse_fasta_header{
   }else{
     $fastaheader=~s/^>//;
     if(valid_ncbi_accession($fastaheader)){
-      print LOG "#Header contains just valid NCBI accession number\n";
       my @ids;
       push(@ids,$fastaheader);
       push(@ids,"scientific name not set");
       return \@ids;
     }else{
-      print LOG "#No valid accession/ ncbi header\n";
       croak ("ERROR [$this_function] \$fasta_path does not contain a valid accession/ ncbi header\n");
     }
   }
