@@ -1,14 +1,14 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-24 14:01:47 mtw>
+# Last changed Time-stamp: <2015-06-29 15:52:54 mtw>
 
 package Bio::ViennaNGS::Util;
 
 use Exporter;
-use version; our $VERSION = qv('0.14');
+use version; our $VERSION = qv('0.15');
 use strict;
 use warnings;
 use Data::Dumper;
-use File::Basename qw(fileparse);
+use File::Basename qw(fileparse basename);
 use IPC::Cmd qw(can_run run);
 use Path::Class qw(dir file);
 use File::Path qw(make_path remove_tree);
@@ -36,8 +36,7 @@ my %unique = ();
 
 sub bed_or_bam2bw {
   my ($type,$infile,$chromsizes,$strand,$dest,$want_norm,$size,$scale,$log) = @_;
-  my ($fn_bg_tmp,$fn_bg,$fn_bw);
-  my ($bn,$path,$ext,$cmd);
+  my ($fn_bg_tmp,$fn_bg,$fn_bw,$fn,$bn,$path,$ext,$cmd);
   my @processed_files = ();
   my $factor = 1.;
   my $this_function = (caller(0))[3];
@@ -72,8 +71,12 @@ sub bed_or_bam2bw {
       if(defined $log);
   }
 
-  ($bn,$path,$ext) = fileparse($infile, qr /\..*/);
-  $fn_bg_tmp  = file($dest,$bn.".tmp.bg");
+  if ($type eq "bam"){$ext = ".bam";}
+  else{$ext = ".bed";}
+  $bn = basename($infile,$ext);
+  $fn = fileparse($infile);
+
+  $fn_bg_tmp  = file($dest,$fn.".tmp.bg");
   $fn_bg      = file($dest,$bn.".bg");
   if($strand eq "+"){
     $fn_bw  = file($dest,$bn.".pos.bw");
